==> texlive-lang_2017.20180305.orig.tar.xz: texlive-lang-2017.20180305/texmf-dist/fonts/source/uptex-fonts/upjisr-h-hk.pl <==
(COMMENT THIS IS A KANJI FORMAT FILE)
(FAMILY UPJIS KANJI)
(FACE F MRR)
(CODINGSCHEME TEX KANJI TEXT)
(DESIGNSIZE R 10.0)
(COMMENT DESIGNSIZE IS IN POINTS)
(COMMENT OTHER SIZES ARE MULTIPLES OF DESIGNSIZE)
(CHECKSUM O 0)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.0)
   (STRETCH R 0.100000)
   (SHRINK R 0.0)
   (XHEIGHT R 1.000000)
   (QUAD R 1.000000)
   (EXTRASPACE R 0.250000)
   (EXTRASTRETCH R 0.200000)
   (EXTRASHRINK R 0.125000)
   )
(GLUEKERN
   (LABEL O 0)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   (LABEL O 1)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   (LABEL O 2)
   (GLUE O 0 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 5 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 6 R 0.500000 R 0.0 R 0.500000)
   (STOP)
   (LABEL O 3)
   (GLUE O 0 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 1 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 2 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 3 R 0.500000 R 0.0 R 0.250000)
   (GLUE O 4 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 5 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 6 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   (LABEL O 4)
   (GLUE O 0 R 0.500000 R 0.0 R 0.0)
   (GLUE O 1 R 0.500000 R 0.0 R 0.0)
   (GLUE O 3 R 0.750000 R 0.0 R 0.250000)
   (GLUE O 5 R 0.500000 R 0.0 R 0.0)
   (GLUE O 6 R 0.500000 R 0.0 R 0.0)
   (STOP)
   (LABEL O 5)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (KRN O 5 R 0.0)
   (STOP)
   (LABEL O 6)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   )
(CHARSINTYPE O 1
   ‘ “ （ 〔 ［ ｛ 〈 《 「 『
   【
   UFF5F U3018 U3016 U301D 
   )
(CHARSINTYPE O 2
   、 ， ’ ” ） 〕 ］ ｝ 〉 》
   」 』 】
   UFF60 U3019 U3017 U301F 
   )
(CHARSINTYPE O 3
   ・ ： ；
   U00B7 
   )
(CHARSINTYPE O 4
   。 ．
   )
(CHARSINTYPE O 5
   — ― … ‥
   )
(CHARSINTYPE O 6
   UFF61 UFF62 UFF63 UFF64 UFF65 UFF66 UFF67
   UFF68 UFF69 UFF6A UFF6B UFF6C UFF6D UFF6E UFF6F
   UFF70 UFF71 UFF72 UFF73 UFF74 UFF75 UFF76 UFF77
   UFF78 UFF79 UFF7A UFF7B UFF7C UFF7D UFF7E UFF7F
   UFF80 UFF81 UFF82 UFF83 UFF84 UFF85 UFF86 UFF87
   UFF88 UFF89 UFF8A UFF8B UFF8C UFF8D UFF8E UFF8F
   UFF90 UFF91 UFF92 UFF93 UFF94 UFF95 UFF96 UFF97
   UFF98 UFF99 UFF9A UFF9B UFF9C UFF9D UFF9E UFF9F
   )
(TYPE O 0
   (CHARWD R 1.000000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      )
   )
(TYPE O 1
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      )
   )
(TYPE O 2
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 0 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 5 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 6 R 0.500000 R 0.0 R 0.500000)
      )
   )
(TYPE O 3
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 0 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 1 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 2 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 3 R 0.500000 R 0.0 R 0.250000)
      (GLUE O 4 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 5 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 6 R 0.250000 R 0.0 R 0.250000)
      )
   )
(TYPE O 4
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 0 R 0.500000 R 0.0 R 0.0)
      (GLUE O 1 R 0.500000 R 0.0 R 0.0)
      (GLUE O 3 R 0.750000 R 0.0 R 0.250000)
      (GLUE O 5 R 0.500000 R 0.0 R 0.0)
      (GLUE O 6 R 0.500000 R 0.0 R 0.0)
      )
   )
(TYPE O 5
   (CHARWD R 1.000000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      (KRN O 5 R 0.0)
      )
   )
(TYPE O 6
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      )
   )

==> texlive-lang_2025.20251127.orig.tar.xz: texlive-lang-2025.20251127/texmf-dist/fonts/source/uptex-fonts/upjisr-h-hk.pl <==
(COMMENT THIS IS A KANJI FORMAT FILE)
(FAMILY UPJIS KANJI)
(FACE F MRR)
(CODINGSCHEME TEX KANJI TEXT)
(DESIGNSIZE R 10.0)
(COMMENT DESIGNSIZE IS IN POINTS)
(COMMENT OTHER SIZES ARE MULTIPLES OF DESIGNSIZE)
(CHECKSUM O 0)
(FONTDIMEN
   (SLANT R 0.0)
   (SPACE R 0.0)
   (STRETCH R 0.100000)
   (SHRINK R 0.0)
   (XHEIGHT R 1.000000)
   (QUAD R 1.000000)
   (EXTRASPACE R 0.250000)
   (EXTRASTRETCH R 0.200000)
   (EXTRASHRINK R 0.125000)
   )
(GLUEKERN
   (LABEL O 0)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   (LABEL O 1)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   (LABEL O 2)
   (GLUE O 0 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 5 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 6 R 0.500000 R 0.0 R 0.500000)
   (STOP)
   (LABEL O 3)
   (GLUE O 0 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 1 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 2 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 3 R 0.500000 R 0.0 R 0.250000)
   (GLUE O 4 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 5 R 0.250000 R 0.0 R 0.250000)
   (GLUE O 6 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   (LABEL O 4)
   (GLUE O 0 R 0.500000 R 0.0 R 0.0)
   (GLUE O 1 R 0.500000 R 0.0 R 0.0)
   (GLUE O 3 R 0.750000 R 0.0 R 0.250000)
   (GLUE O 5 R 0.500000 R 0.0 R 0.0)
   (GLUE O 6 R 0.500000 R 0.0 R 0.0)
   (STOP)
   (LABEL O 5)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (KRN O 5 R 0.0)
   (STOP)
   (LABEL O 6)
   (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
   (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
   (STOP)
   )
(CHARSINTYPE O 1
   ‘ “ （ 〔 ［ ｛ 〈 《 「 『
   【
   UFF5F U3018 U3016 U301D U00AB 
   U2329 U301A 
   )
(CHARSINTYPE O 2
   、 ， ’ ” ） 〕 ］ ｝ 〉 》
   」 』 】
   UFF60 U3019 U3017 U301F U00BB 
   U232A U301B U301E 
   )
(CHARSINTYPE O 3
   ・ ： ；
   U00B7 
   )
(CHARSINTYPE O 4
   。 ．
   )
(CHARSINTYPE O 5
   — ― … ‥
   )
(CHARSINTYPE O 6
   UFF61 UFF62 UFF63 UFF64 UFF65 UFF66 UFF67
   UFF68 UFF69 UFF6A UFF6B UFF6C UFF6D UFF6E UFF6F
   UFF70 UFF71 UFF72 UFF73 UFF74 UFF75 UFF76 UFF77
   UFF78 UFF79 UFF7A UFF7B UFF7C UFF7D UFF7E UFF7F
   UFF80 UFF81 UFF82 UFF83 UFF84 UFF85 UFF86 UFF87
   UFF88 UFF89 UFF8A UFF8B UFF8C UFF8D UFF8E UFF8F
   UFF90 UFF91 UFF92 UFF93 UFF94 UFF95 UFF96 UFF97
   UFF98 UFF99 UFF9A UFF9B UFF9C UFF9D UFF9E UFF9F
   )
(TYPE O 0
   (CHARWD R 1.000000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      )
   )
(TYPE O 1
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      )
   )
(TYPE O 2
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 0 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 5 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 6 R 0.500000 R 0.0 R 0.500000)
      )
   )
(TYPE O 3
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 0 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 1 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 2 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 3 R 0.500000 R 0.0 R 0.250000)
      (GLUE O 4 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 5 R 0.250000 R 0.0 R 0.250000)
      (GLUE O 6 R 0.250000 R 0.0 R 0.250000)
      )
   )
(TYPE O 4
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 0 R 0.500000 R 0.0 R 0.0)
      (GLUE O 1 R 0.500000 R 0.0 R 0.0)
      (GLUE O 3 R 0.750000 R 0.0 R 0.250000)
      (GLUE O 5 R 0.500000 R 0.0 R 0.0)
      (GLUE O 6 R 0.500000 R 0.0 R 0.0)
      )
   )
(TYPE O 5
   (CHARWD R 1.000000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      (KRN O 5 R 0.0)
      )
   )
(TYPE O 6
   (CHARWD R 0.500000)
   (CHARHT R 0.880000)
   (CHARDP R 0.120000)
   (COMMENT
      (GLUE O 1 R 0.500000 R 0.0 R 0.500000)
      (GLUE O 3 R 0.250000 R 0.0 R 0.250000)
      )
   )
